==> alfresco-repository-23.7.0.12-sources.jar: org/alfresco/util/QNameTypeEditor.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.util;

import java.beans.PropertyEditorSupport;

import org.alfresco.service.namespace.NamespaceService;
import org.alfresco.service.namespace.QName;

/**
 * QName type editor.
 *
 * @author Roy Wetherall
 * @since 5.0
 */
public class QNameTypeEditor extends PropertyEditorSupport
{
    /** namespace service */
    private NamespaceService namespaceService;

    /**
     * @param namespaceService  namespace service
     */
    public QNameTypeEditor(NamespaceService namespaceService)
    {
        this.namespaceService = namespaceService;
    }

    /**
     * @see java.beans.PropertyEditorSupport#setAsText(java.lang.String)
     */
    @Override
    public void setAsText(String text)
    {
        // convert prefix string to QName
        setValue(QName.createQName(text, namespaceService));
    }
}

==> alfresco-repository-25.4.0.2-sources.jar: org/alfresco/util/QNameTypeEditor.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.util;

import java.beans.PropertyEditorSupport;

import org.alfresco.service.namespace.NamespaceService;
import org.alfresco.service.namespace.QName;

/**
 * QName type editor.
 *
 * @author Roy Wetherall
 * @since 5.0
 */
public class QNameTypeEditor extends PropertyEditorSupport
{
    /** namespace service */
    private NamespaceService namespaceService;

    /**
     * @param namespaceService
     *            namespace service
     */
    public QNameTypeEditor(NamespaceService namespaceService)
    {
        this.namespaceService = namespaceService;
    }

    /**
     * @see java.beans.PropertyEditorSupport#setAsText(java.lang.String)
     */
    @Override
    public void setAsText(String text)
    {
        // convert prefix string to QName
        setValue(QName.createQName(text, namespaceService));
    }
}
